namespace Eco.Mods.TechTree
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using Eco.Core.Utils;
    using Eco.Core.Utils.AtomicAction;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Property;
    using Eco.Gameplay.Skills;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Services;
    using Eco.Shared.Utils;
    using Gameplay.Systems.Tooltip;

    //Builder Specialization Mod: Free skill - individual construction skills will be more expensive to offset for this
    [Serialized]
    [RequiresSkill(typeof(SurvivalistSkill), 0)]
    public partial class BuilderSkill : Skill
    {
        public override string FriendlyName { get { return "Builder"; } }
        public override string Description { get { return Localizer.Do("Learn how to deal with the materials of the world around you."); } }
        
        public static int[] SkillPointCost = { 0 };
        public override int RequiredPoint { get { return 0; } }
        public override int PrevRequiredPoint { get { return 0; } }
        public override int MaxLevel { get { return 0; } }
    }

    [Serialized]
    public partial class BuilderSkillBook : SkillBook<BuilderSkill, BuilderSkillScroll>
    {
        public override string FriendlyName { get { return "Builder Skill Book"; } }
    }

    [Serialized]
    public partial class BuilderSkillScroll : SkillScroll<BuilderSkill, BuilderSkillBook>
    {
        public override string FriendlyName { get { return "Builder Skill Scroll"; } }
    }


    public partial class BuilderSkillBookRecipe : Recipe
    {
        public BuilderSkillBookRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<BuilderSkillBook>(),
            };
            this.Ingredients = new CraftingElement[]
            {
                //Specialized Builder: Costs from all Construction research
                new CraftingElement<HewnLogItem>(typeof(ResearchEfficiencySkill), 10, ResearchEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<MortaredStoneItem>(typeof(ResearchEfficiencySkill), 10, ResearchEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<SandItem>(typeof(ResearchEfficiencySkill), 10, ResearchEfficiencySkill.MultiplicativeStrategy),
                new CraftingElement<IronOreItem>(typeof(ResearchEfficiencySkill), 60, ResearchEfficiencySkill.MultiplicativeStrategy)

            };
            this.CraftMinutes = new ConstantValue(10);

            this.Initialize("Builder Skill Book", typeof(BuilderSkillBookRecipe));
            CraftingComponent.AddRecipe(typeof(ResearchTableObject), this);
        }
    }
}
